# SS13 tools

[![PyLint](https://github.com/RigglePrime/SS13-tools/actions/workflows/pylint.yml/badge.svg)](https://github.com/RigglePrime/SS13-tools/actions/workflows/pylint.yml)
[![Flake8](https://github.com/RigglePrime/SS13-tools/actions/workflows/flake8-lint.yml/badge.svg)](https://github.com/RigglePrime/SS13-tools/actions/workflows/flake8-lint.yml)
[![Build](https://github.com/RigglePrime/SS13-tools/actions/workflows/publish.yml/badge.svg)](https://github.com/RigglePrime/SS13-tools/actions/workflows/publish.yml)

A set of tools to help with automating tasks for the /tg/ branch of SS13.

Made for Python 3.9+

## How to run

`pip install ss13-tools; python -m ss13_tools` (pip3 on Linux) or dowload the executable [here](https://github.com/RigglePrime/SS13-tools/releases/latest)

## Contents

- auth (TODO)
- byond: tools for working with BYOND, such as checking if a ckey exists
- [centcom](https://centcom.melonmesa.com/)
- log_downloader: downloads logs from tg's [parsed logs](https://tgstation13.org/parsed-logs)
- scrubby: scrubby tools
- slur_detector: what it says on the tin

## Downloading

For compiled versions, see [this](https://github.com/RigglePrime/admin-tools/releases) link

Now also available on [PyPi](https://pypi.org/project/ss13-tools/)!
